Learn R Programming

lsplsGlm (version 1.0)

CentralCNS: Gene expression and clinical data used to predict tumors of Central Nervous System from children

Description

Gene expression (60x7129) and clinical data (60x4) are used to predict the response of childhood malignant embryonal tumors of Central Nervous System (CNS) to therapy.

Usage

data(CentralCNS)

Arguments

Value

X

a data gene matrix (60x7129) giving the expression levels of 7129 genes for the 60 patients. Each row corresponds to a patient, each column to a gene.

D

a data matrix (60x4) of clinical data. Each row corresponds to a patient and each column to a clinical variable.

Y

a numeric vector of length 60 giving the condition of the patient (1 dead, 0 alive).

Details

The dataset is composed of 60 patients samples, 21 patients died and 39 survived within 24 months. There are two matrices: genetic data X of size 60x7129 and clinical data D of size 60x4. There is also a response variable Y of size 60x1.

Examples

Run this code
# NOT RUN {
# load dataset
data(CentralCNS)

# how many patients and how many genes ?
dim(CentralCNS$X)

# how many patients of class 0 and 1 respectively ?
sum(CentralCNS$Y==0)
sum(CentralCNS$Y==1)
# }

Run the code above in your browser using DataLab